// AdminView.js

import { useState, useEffect } from 'react';
import { Table } from 'react-bootstrap';
import EditCourse from './EditCourse';
import ArchiveCourse from './ArchiveCourse';

const fetchDataFromDatabase = async () => {
  try {
    const response = await fetch(`${process.env.REACT_APP_API_URL}/courses/all`);
    const data = await response.json();
    return data;
  } catch (error) {
    throw new Error('Error fetching data from the database');
  }
};

export default function AdminView() {
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [courses, setCourses] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      try {
        setLoading(true);
        const data = await fetchDataFromDatabase();
        setCourses(data.map(course => (
          <tr key={course._id}>
            <td>{course._id}</td>
            <td>{course.name}</td>
            <td>{course.description}</td>
            <td>{course.price}</td>
            <td className={course.isActive ? 'text-success' : 'text-danger'}>
              {course.isActive ? 'Available' : 'Unavailable'}
            </td>
            <td><EditCourse course={course._id} fetchData={fetchData} /></td>
            <td>
              <ArchiveCourse
                course={course._id}
                fetchData={fetchData}
                isActive={course.isActive}
              />
            </td>
          </tr>
        )));
      } catch (error) {
        setError(error.message || 'An error occurred');
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  return (
    <>
      <h1 className="text-center my-4"> Admin Dashboard</h1>

      {loading && <p>Loading...</p>}
      {error && <p style={{ color: 'red' }}>{error}</p>}

      {!loading && !error && (
        <Table striped bordered hover responsive>
          <thead>
            <tr className="text-center">
              <th>ID</th>
              <th>Name</th>
              <th>Description</th>
              <th>Price</th>
              <th>Availability</th>
              <th colSpan="2">Actions</th>
            </tr>
          </thead>

          <tbody>
            {courses}
          </tbody>
        </Table>
      )}
    </>
  );
}
